==> plugin.video.srfplaytv-1.6.0.zip: plugin.video.srfplaytv/README.md <==
# SRF Play TV

[![Codacy Badge](https://api.codacy.com/project/badge/Grade/1aae1595af1f4f75bd805bc03cc17215)](https://www.codacy.com/app/goggle/plugin.video.srfplaytv?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=goggle/plugin.video.srfplaytv&amp;utm_campaign=Badge_Grade)

<img src="https://github.com/goggle/plugin.video.srfplaytv/raw/master/resources/icon.png" width="256">

**SRF Play TV** (plugin.video.srfplaytv) is a Kodi plugin to access the video library of the Swiss Radio and Television (SRF).
This repository is kept as minimal as possible. All the relevant code resides in [script.module.srgssr](https://github.com/goggle/script.module.srgssr).

## Goals of the plugin
Bring the full power of the [SRF Play TV media library](https://www.srf.ch/play/tv) on your TV (or another device) via [Kodi](https://kodi.tv/). The plugin aims to be close to the original media library, so that the experience of consuming media through the browser or through Kodi should be similar.

## Features
 - [x] Overview over all the shows.
 - [x] Manage a list of your favourite SRF shows and get a list of your recently aired favourite shows.
 - [x] List and play segments for shows (if available), so you don't have to watch the whole episode if you are only interested in a specific section.
 - [x] Various lists: Newest and most clicked shows by topic (e.g. News, Documentaries, etc.), trending shows, soon offline shows, shows by date.
 - [x] Search videos and shows.
 - [x] Choose between SD and HD quality.
 - [x] Subtitle support.
 - [x] Livestreams that are exclusively broadcasted on SRF.ch (only available in Switzerland).
 - [ ] Live TV support: SRF 1, SRF 2 and SRF info (only available in Switzerland).
 - [x] SRF on YouTube: Browse the official SRF channels on YouTube.

## Installation

 - The plugin is available in the official "Kodi Add-on repository". This is the recommended way to get the plugin.
 - You can download the newest release as a zip file from the [release section](https://github.com/goggle/plugin.video.srfplaytv/releases) on github and manually install the plugin from the zip file. Keep in mind that you won't get any automatic updates if you choose this method.

## Support this plugin
How you can help improving this plugin:
 - For bugs and feature requests use the [issue tracker](https://github.com/goggle/plugin.video.srfplaytv/issues) on the github page.
 - Feel free to submit a pull request. Please style your code according to [PEP 8](https://www.python.org/dev/peps/pep-0008/).

If you like this plugin, consider to make a donation to the author:

| Method | Link / Address | QR code |
| --- | --- | --- |
| Paypal | [Donation link](https://www.paypal.com/cgi-bin/webscr?cmd=_s-xclick&hosted_button_id=ZXAFRHTZGRARS) | ![Paypal link](https://raw.githubusercontent.com/goggle/plugin.video.srfplaytv/e62b52bb394eeee98c929895005bbc33e6028770/paypal.png) |
| Bitcoin | 14d2as82kQ3mRoCSyrnHNoDi8PkFvxMMgP | ![Bitcoin address](https://raw.githubusercontent.com/goggle/plugin.video.srfplaytv/af1c696004d9b42c730dc55f7e66596ec3521b99/bitcoin.png) |


## Screenshots
![Main menu](https://raw.githubusercontent.com/goggle/plugin.video.srfplaytv/master/resources/screenshot-01.png)
![A list menu](https://raw.githubusercontent.com/goggle/plugin.video.srfplaytv/master/resources/screenshot-02.png)
![Episode information](https://raw.githubusercontent.com/goggle/plugin.video.srfplaytv/master/resources/screenshot-03.png)

## Thanks
 - Thanks to @giovannipessiva for providing an Italian translation.
 - Thanks @nmielec for providing a French translation.

==> plugin.video.srfplaytv-2.2.2.zip: plugin.video.srfplaytv/README.md <==
# SRF Play TV

<img src="https://github.com/goggle/plugin.video.srfplaytv/raw/master/resources/icon.png" width="256">

**SRF Play TV** (plugin.video.srfplaytv) is a Kodi plugin to access the video library of the Swiss Radio and Television (SRF).
This repository is kept as minimal as possible. All the relevant code resides in [script.module.srgssr](https://github.com/goggle/script.module.srgssr).

## Goals of the plugin
Get the [SRF Play TV media library](https://www.srf.ch/play/tv) on your TV (or another device) via [Kodi](https://kodi.tv/). The plugin aims to be close to the original media library, so that the experience of consuming media through the browser or through Kodi should be similar.

## Features
 - [x] Overview over all the shows
 - [x] Manage a list of your favourite SRF shows and get a list of your recently aired favourite shows
 - [x] Videos presented on homepage
 - [x] Topics
 - [x] Shows by date
 - [x] Search videos
 - [x] Choose between SD and HD quality
 - [x] Subtitle support
 - [x] Livestreams
 - [x] SRF on YouTube: Browse the official SRF channels on YouTube.

## Installation

 - The plugin is available in the official "Kodi Add-on repository". This is the recommended way to get the plugin.
 - You can download the newest release as a zip file from the [release section](https://github.com/goggle/plugin.video.srfplaytv/releases) on github and manually install the plugin from the zip file. If you choose this method, make sure to have all the dependencies installed, especially
   - [script.module.srgssr](https://github.com/goggle/script.module.srgssr)
   - [script.module.youtube_channels](https://github.com/goggle/script.module.youtube_channels)

   Keep in mind that you won't get any automatic updates if you choose this method.

## Support this plugin
How you can help improving this plugin:
 - For bugs and feature requests use the [issue tracker](https://github.com/goggle/plugin.video.srfplaytv/issues) on the github page.
 - Feel free to submit a pull request. Please style your code according to [PEP 8](https://www.python.org/dev/peps/pep-0008/).

If you like this plugin, consider to make a donation to the author:

| Method | Link / Address | QR code |
| --- | --- | --- |
| Paypal | [Donation link](https://www.paypal.com/cgi-bin/webscr?cmd=_s-xclick&hosted_button_id=ZXAFRHTZGRARS) | ![Paypal link](https://raw.githubusercontent.com/goggle/plugin.video.srfplaytv/e62b52bb394eeee98c929895005bbc33e6028770/paypal.png) |
| Bitcoin | 14d2as82kQ3mRoCSyrnHNoDi8PkFvxMMgP | ![Bitcoin address](https://raw.githubusercontent.com/goggle/plugin.video.srfplaytv/af1c696004d9b42c730dc55f7e66596ec3521b99/bitcoin.png) |


## Screenshots
![Main menu](https://raw.githubusercontent.com/goggle/plugin.video.srfplaytv/master/resources/screenshot-01.png)
![A list menu](https://raw.githubusercontent.com/goggle/plugin.video.srfplaytv/master/resources/screenshot-02.png)
![Episode information](https://raw.githubusercontent.com/goggle/plugin.video.srfplaytv/master/resources/screenshot-03.png)

## Thanks
 - Thanks to @giovannipessiva for providing an Italian translation.
 - Thanks @nmielec for providing a French translation.
